pub struct DetailedFlavorQuery { /* private fields */ }Expand description
A detailed query to flavor list.
Implementations
Sourceimpl DetailedFlavorQuery
impl DetailedFlavorQuery
Sourcepub fn into_stream(self) -> impl Stream<Item = Result<Flavor>>
pub fn into_stream(self) -> impl Stream<Item = Result<Flavor>>
Convert this query into a stream executing the request.
This stream yields full Flavor objects.
Returns a TryStream, which is a stream with each next
call returning a Result.
Note that no requests are done until you start iterating.