[][src]Struct openstack::image::ImageQuery

pub struct ImageQuery { /* fields omitted */ }

A query to image list.

Methods

impl ImageQuery[src]

pub fn sort_by(self, sort: Sort<ImageSortKey>) -> Self[src]

Add sorting to the request.

pub fn with_marker<T: Into<String>>(self, marker: T) -> Self[src]

Add marker to the request.

Using this disables automatic pagination.

pub fn with_limit(self, limit: usize) -> Self[src]

Add limit to the request.

Using this disables automatic pagination.

pub fn with_name<T: Into<String>>(self, value: T) -> Self[src]

Filter by image name.

pub fn with_status<T: Into<ImageStatus>>(self, value: T) -> Self[src]

Filter by image status.

pub fn with_visibility<T: Into<ImageVisibility>>(self, value: T) -> Self[src]

Filter by visibility.

pub fn into_iter(self) -> ResourceIterator<ImageQuery>[src]

Convert this query into an iterator executing the request.

Returns a FallibleIterator, which is an iterator with each next call returning a Result.

Note that no requests are done until you start iterating.

pub fn all(self) -> Result<Vec<Image>>[src]

Execute this request and return all results.

A convenience shortcut for self.into_iter().collect().

pub fn one(self) -> Result<Image>[src]

Return one and exactly one result.

Fails with ResourceNotFound if the query produces no results and with TooManyItems if the query produces more than one result.